import { PageDataChange, PageModeChange } from "../control/events";
import { Relationship } from "../svi-datahub";
import { QueryMode } from "../svi-sand";
import { ControlContainer, VIObject } from "../object/object-api";
import { PageModel, PageModelObjectData } from "../page-model/page-model-api";
import { SearchObject, SearchQuery } from "../search/client/client-search-api";
import { HandleType, MinMaxDates, TimeSliderContextMenuHideOptions, TimeSliderEventDates, TimeSliderRange, TimeSliderRangeChangedEvent } from "../time-slider";
import { PageModeEvent } from "../control";
export interface SearchAndSelectWithPreviewInputBindings {
    initialQuery?: string;
    additionalModes?: QueryMode[];
    objectTypeFilter?: string[];
}
export interface SearchAndSelectWithPreviewBindings extends SearchAndSelectWithPreviewInputBindings {
    onSearchItemSelected: (selectedItem: SearchObject | null) => void;
    onSearchItemDoubleClicked?: (selectedItem: SearchObject) => void;
}
export interface PageViewerApi {
    save: () => Promise<void>;
    isDirty: () => boolean;
    isValid: () => Promise<boolean>;
}
export type PageViewerBindings = CreateObjectPageBindings | EditObjectPageBindings | ViewObjectPageBindings | StaticDataPageBindings | PageBindings;
export declare enum PageViewerBindingsType {
    CreateObject = "CREATE",
    EditObject = "EDIT",
    ViewObject = "VIEW",
    StaticData = "STATIC"
}
/**
 * Component bindings to configure a page viewer for creating a new object.
 */
export interface CreateObjectPageBindings extends CommonPageViewerBindings {
    bindingsType: PageViewerBindingsType.CreateObject;
    /** Page context to use. */
    eventName: PageModeEvent.CREATE;
    /** Entity type of the object. */
    docType: string;
    /** Temporary ID to use for the unsaved object. */
    tempCreateId?: string;
    /** Initial values to populate the pageModel data. */
    initialCreateData?: Record<string, any>;
    /**
     * Optionally provide a pageModel using window.sas.vi.pageModel.createFromObject.
     * The pageModel type must match docType.
     * The pageModel data will be populated with initialCreateData.
     * The pageModel can be used to inspect current data and validity
     * but the reference to this model will be broken if a new template is to be loaded due to a mode transition or other condition.
     * Prefer using setApi and onChange to interact with the page.
     */
    pageModel?: PageModel;
}
/**
 * Component bindings to configure a page viewer for editing an existing object.
 */
export interface EditObjectPageBindings extends CommonPageViewerBindings {
    bindingsType: PageViewerBindingsType.EditObject;
    /** Page context to use. */
    eventName: PageModeEvent.EDIT;
    /** Entity type of the object. */
    docType: string;
    /** Object ID */
    docId: string;
    /** Use the given page template by UUID regardless of page context. */
    templateUuid?: string;
    /**
     * Optionally provide a pageModel using window.sas.vi.pageModel.createFromObject.
     * The pageModel type must match docType.
     * The pageModel data will be populated using the loaded object response from the given docType and docId.
     * The pageModel can be used to inspect current data and validity
     * but the reference to this model will be broken if a new template is to be loaded due to a mode transition or other condition.
     * Prefer using setApi and onChange to interact with the page.
     */
    pageModel?: PageModel;
}
/**
 * Component bindings to configure a page viewer for a read-only view of an existing object.
 */
export interface ViewObjectPageBindings extends CommonPageViewerBindings {
    bindingsType: PageViewerBindingsType.ViewObject;
    /** Page context to use. */
    eventName: PageModeEvent.OPEN | PageModeEvent.INSPECT | PageModeEvent.SUMMARY;
    /** Entity type of the object. */
    docType: string;
    /** Object ID */
    docId: string;
    /** Use the given page template by UUID regardless of page context. */
    templateUuid?: string;
}
/**
 * Component bindings to configure a page viewer for a read-only view of static object data.
 */
export interface StaticDataPageBindings extends CommonPageViewerBindings {
    bindingsType: PageViewerBindingsType.StaticData;
    /** Object data to create the page response. */
    staticDocumentData: VIObject;
}
export interface CommonPageViewerBindings {
    /** Show the page toolbar. This contains the toolbar actions associated with the object's Entity type. */
    showToolbar?: boolean;
    /**
     * Assign the given CSS classes to the page viewer's container.
     * This is the element which encompasses the main document view and the toolbar.
     */
    containerClass?: string;
    /** If true, the page viewer will fill its parent element's height. */
    fitToContainerHeight?: boolean;
    /**
     * Assign the given CSS classes to the page viewer's main section.
     * This is the element which displays the main document, excluding toolbar.
     */
    pageClass?: string;
    /**
     * Enable workspace and insight tabs to be rendered.
     */
    enableSheets?: boolean;
    /**
     * A callback which is called when the page viewer is initialized.
     * It provides an API which can be used to check the page viewer state and save the document.
     */
    setApi?: (api: PageViewerApi) => void;
    /** A callback which is called when the page viewer dirty state changes. */
    onDirty?: (isDirty: boolean) => void;
    /** A callback which is called when the pageModel's mode or data changes. */
    onChange?: (change: PageDataChange | PageModeChange) => void;
}
/** @deprecated use {@link PageViewerBindings} */
export interface PageBindings {
    bindingsType?: never;
    docId?: string;
    docType?: string;
    eventName?: string;
    templateUuid?: string;
    showToolbar?: boolean;
    tempCreateId?: string;
    containerClass?: string;
    fitToContainerHeight?: boolean;
    pageClass?: string;
    enableSheets?: string;
    pageModel?: PageModel;
    staticDocumentData?: Record<string, any>;
    initialCreateData?: Record<string, any>;
    setApi?: (api: PageViewerApi) => void;
    mainTab?: string;
    onDirty?: (isDirty: boolean) => void;
    onChange?: (change: PageDataChange | PageModeChange) => void;
}
export interface PagePreviewBindings {
    templateUuid: string;
}
export interface ControlCollectionBindings {
    controlContainer?: ControlContainer;
    pageModel?: PageModel;
    root?: boolean;
}
export interface RelationshipDetailsBindings {
    targetObjectTypeName: string;
    targetObjectTypeLabel: string;
    parentObjectTypeName: string;
    parentObjectTypeLabel: string;
    linkReasons: Relationship[];
    selectedItem?: {
        id: string;
        type: string;
    };
    newPageModel?: {
        model: PageModelObjectData;
    };
    onLinkReasonSelected: (linkReason: Relationship) => void;
    relationshipValues?: Record<string, any>;
    initialCreateData?: Record<string, any>;
    setApi?: (api: PageViewerApi) => void;
    onRelatedPageChange?: (change: PageDataChange | PageModeChange) => void;
    onRelationshipValuesChange?: (current: Record<string, any>, previous?: Record<string, any>) => void;
}
export interface SearchInputInputBindings {
    entityName: string;
    queryBuilderId?: string;
    showQueryBuilder?: boolean;
    queryText?: string;
    autoFocus?: boolean;
    queryBuilderOkButtonLabel?: string;
    queryModel?: QueryBuilderModel;
    performSearch?: boolean;
}
export interface QueryBuilderModel {
    manualQueryString?: string;
    model: QueryBuilderEntityModel[];
}
export interface QueryBuilderEntityModel {
    entity: string;
    queries: QueryBuilderItem[];
    singleChildSearch?: boolean;
}
export interface QueryBuilderItem {
    booleanValue?: boolean | string;
    boost?: number;
    dateTimeValue?: string | Date;
    dateValue?: string | Date;
    exclude?: boolean;
    field?: string;
    fromDateTimeValue?: string | Date;
    fromDateValue?: string | Date;
    fromNumericValue?: number;
    numericValue?: number;
    operator?: string;
    phonetic?: boolean;
    previousField?: string;
    proximity?: number;
    rangeValidationError?: boolean;
    referenceValue?: string;
    relationshipField?: boolean;
    relationshipTypeValue?: string;
    relativeDateDatetimeNumericValue?: number;
    relativeDateDatetimeUnitsValue?: string;
    stringValidationError?: boolean;
    synonym?: boolean;
    textValue?: string;
    toDateTimeValue?: string | Date;
    toDateValue?: string | Date;
    toNumericValue?: number;
    userGroupValue?: Array<{
        id: string;
        type: string;
    }>;
}
export interface SearchInputBindings extends SearchInputInputBindings {
    onSearch?: (model: SearchQuery) => void;
    onValueChange?: (val: string) => void;
}
export interface TimeSliderInputBindings {
    timeSliderId: string;
    timeSliderDates: TimeSliderEventDates;
    viewRange: TimeSliderRange;
    handleType?: HandleType;
    isReadOnly?: boolean;
    sliderWidth?: number;
    disableSwitchHandleType?: boolean;
    contextMenuHideOptions: TimeSliderContextMenuHideOptions;
    minMaxDates?: MinMaxDates;
}
export interface TimeSliderBindings extends TimeSliderInputBindings {
    rangeChangeEvent?: (rangeChangedEvent: TimeSliderRangeChangedEvent) => void;
    handleTypeChange?: (handleType: HandleType) => void;
    onLoad?: () => void;
    close?: () => void;
}
export type SviComponentBindings = ControlCollectionBindings | RelationshipDetailsBindings | SearchInputBindings | PageViewerBindings | PagePreviewBindings | SearchAndSelectWithPreviewBindings | TimeSliderBindings;
